@@ -5,7 +5,7 @@
 Internal configuration for ``sphinx-toolbox``.
 """
 #
-#  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
+#  Copyright © 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -30,15 +30,13 @@ Internal configuration for ``sphinx-toolbox``.
 from typing import List
 
 # 3rd party
-from apeye.url import RequestsURL
-from domdf_python_tools.stringlist import StringList
+from apeye.requests_url import RequestsURL
 from sphinx.application import Sphinx
-from sphinx.config import Config
 
 # this package
-from sphinx_toolbox.utils import make_github_url
+from sphinx_toolbox.utils import Config, add_nbsp_substitution
 
-__all__ = ["MissingOptionError", "InvalidOptionError", "validate_config", "ToolboxConfig"]
+__all__ = ("MissingOptionError", "InvalidOptionError", "validate_config", "ToolboxConfig")
 
 
 class MissingOptionError(ValueError):
@@ -72,8 +70,12 @@ class ToolboxConfig(Config):
 	#: The username of the GitHub account that owns the repository this documentation corresponds to.
 	github_username: str
 
-	#: The GitHub repository this documentation corresponds to.
 	github_repository: str
+	"""
+	The GitHub repository this documentation corresponds to.
+
+	.. clearpage::
+	"""
 
 	#: The complete URL of the repository on GitHub.
 	github_url: RequestsURL
@@ -116,40 +118,20 @@ class ToolboxConfig(Config):
 	"""
 
 
-def validate_config(app: Sphinx, config: ToolboxConfig):
-	r"""
+def validate_config(app: Sphinx, config: ToolboxConfig) -> None:
+	"""
 	Validate the provided configuration values.
 
-
 	See :class:`~sphinx_toolbox.config.ToolboxConfig` for a list of the configuration values.
 
-	:param app: The Sphinx app.
+	:param app: The Sphinx application.
 	:param config:
 	:type config: :class:`~sphinx.config.Config`
 	"""
 
-	config.source_link_target = str(config.source_link_target).lower().strip()
+	# this package
+	from sphinx_toolbox import github, source
 
-	if config.source_link_target not in {"sphinx", "github"}:
-		raise InvalidOptionError("Invalid value for 'source_link_target'.")
-
-	if not config.github_username:
-		raise MissingOptionError("The 'github_username' option is required.")
-	else:
-		config.github_username = str(config.github_username)
-
-	if not config.github_repository:
-		raise MissingOptionError("The 'github_repository' option is required.")
-	else:
-		config.github_repository = str(config.github_repository)
-
-	config.github_url = make_github_url(config.github_username, config.github_repository)
-	config.github_source_url = config.github_url / "blob" / "master"
-	config.github_issues_url = config.github_url / "issues"
-	config.github_pull_url = config.github_url / "pull"
-
-	rst_prolog = StringList(config.rst_prolog or '')
-	nbsp_sub = ".. |nbsp| unicode:: 0xA0\n   :trim:"
-	if nbsp_sub not in rst_prolog:
-		rst_prolog.append(nbsp_sub)
-	config.rst_prolog = str(rst_prolog)
+	source._configure(app, config)
+	github.validate_config(app, config)
+	add_nbsp_substitution(config)
