@@ -4,9 +4,8 @@
 """
 reStructuredText XRef role for decorators.
 
-.. extensions:: sphinx_toolbox.decorators
-
 .. versionadded:: 0.9.0
+.. extensions:: sphinx_toolbox.decorators
 
 
 Usage
@@ -29,6 +28,9 @@ Usage
 		:deco:`Title <my_decorator>`
 
 
+.. latex:clearpage::
+
+
 API Reference
 ----------------
 
@@ -94,7 +96,7 @@ from sphinx.environment import BuildEnvironment
 # this package
 from sphinx_toolbox.utils import SphinxExtMetadata, metadata_add_version
 
-__all__ = ["PyDecoXRefRole", "setup"]
+__all__ = ("PyDecoXRefRole", "setup")
 
 
 class PyDecoXRefRole(PyXRefRole):
@@ -102,14 +104,25 @@ class PyDecoXRefRole(PyXRefRole):
 	XRef Role for decorators members.
 	"""
 
-	def process_link(  # noqa D102
-		self,
-		env: BuildEnvironment,
-		refnode: Element,
-		has_explicit_title: bool,
-		title: str,
-		target: str,
-		) -> Tuple[str, str]:
+	def process_link(
+			self,
+			env: BuildEnvironment,
+			refnode: Element,
+			has_explicit_title: bool,
+			title: str,
+			target: str,
+			) -> Tuple[str, str]:
+		"""
+		Called after parsing title and target text, and creating the reference node (given in ``refnode``).
+
+		This method can alter the reference node and must return a new (or the same) ``(title, target)`` tuple.
+
+		:param env:
+		:param refnode:
+		:param has_explicit_title:
+		:param title:
+		:param target:
+		"""
 
 		target = target.lstrip('@')
 
@@ -124,6 +137,9 @@ class PyDecoXRefRole(PyXRefRole):
 		if not has_explicit_title and not title.startswith('@'):
 			title = f"@{title}"
 
+		# Ensure the reference is correctly found in the broader scope.
+		refnode["reftype"] = "obj"
+
 		return title, target
 
 
@@ -132,7 +148,7 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 	"""
 	Setup :mod:`sphinx_toolbox.decorators`.
 
-	:param app: The Sphinx app.
+	:param app: The Sphinx application.
 	"""
 
 	app.add_role_to_domain("py", "deco", PyDecoXRefRole())
