@@ -5,8 +5,8 @@ r"""
 .. extensions:: sphinx_toolbox.installation
 
 
-Usage
--------
+Configuration
+--------------
 
 .. confval:: conda_channels
 	:type: :class:`~typing.List`\[:class:`str`\]
@@ -14,57 +14,21 @@ Usage
 	:default: ``[]``
 
 	The conda channels required to install the library from Anaconda.
+
 	An alternative to setting it within the :rst:dir:`installation` directive.
 
 
-.. rst:directive:: extensions
+Usage
+-------
 
-	Shows instructions on how to enable a Sphinx extension.
-
-	Takes a single argument -- the name of the extension.
-
-	.. rst:directive:option:: import-name
-		:type: string
-
-		The name used to import the extension, if different from the name of the extension.
-
-	.. rst:directive:option:: no-preamble
-		:type: flag
-
-		Disables the preamble text.
-
-	.. rst:directive:option:: no-postamble
-		:type: flag
-
-		Disables the postamble text.
-
-	.. rst:directive:option:: first
-		:type: flag
-
-		Puts the entry for extension before its dependencies.
-		By default is is placed at the end.
-
-		.. versionadded:: 0.4.0
-
-
-	**Example**
-
-	.. rest-example::
-
-		.. extensions:: sphinx-toolbox
-			:import-name: sphinx_toolbox
-
-			sphinx.ext.viewcode
-			sphinx_tabs.tabs
-			sphinx-prompt
-
-
-.. rst:directive:: installation
+.. rst:directive:: .. installation:: name
 
 	Adds a series of tabs providing installation instructions for the project from a number of sources.
 
-	The directive has a single required argument -- the name of the project.
-	If the project uses a different name on PyPI and/or Anaconda, the ``pypi-name`` and ``conda-name`` options can be used to set the name for those repositories.
+	The directive takes a single required argument -- the name of the project.
+	If the project uses a different name on PyPI and/or Anaconda,
+	the ``:pypi-name:`` and ``:conda-name:`` options can be used to set the name
+	for those repositories.
 
 	.. rst:directive:option:: pypi
 		:type: flag
@@ -114,7 +78,7 @@ Usage
 		See :mod:`sphinx_toolbox.github` for more information.
 
 
-	**Example**
+	:bold-title:`Example`
 
 	.. rest-example::
 
@@ -125,11 +89,54 @@ Usage
 			:github:
 
 
+
+.. rst:directive:: extensions
+
+	Shows instructions on how to enable a Sphinx extension.
+
+	The directive takes a single argument -- the name of the extension.
+
+	.. rst:directive:option:: import-name
+		:type: string
+
+		The name used to import the extension, if different from the name of the extension.
+
+	.. rst:directive:option:: no-preamble
+		:type: flag
+
+		Disables the preamble text.
+
+	.. rst:directive:option:: no-postamble
+		:type: flag
+
+		Disables the postamble text.
+
+	.. rst:directive:option:: first
+		:type: flag
+
+		Puts the entry for extension before its dependencies.
+		By default is is placed at the end.
+
+		.. versionadded:: 0.4.0
+
+
+	:bold-title:`Example`
+
+	.. rest-example::
+
+		.. extensions:: sphinx-toolbox
+			:import-name: sphinx_toolbox
+
+			sphinx.ext.viewcode
+			sphinx_tabs.tabs
+			sphinx-prompt
+
+
 API Reference
 --------------
 """  # noqa: D400
 #
-#  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
+#  Copyright © 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -152,8 +159,10 @@ API Reference
 
 # stdlib
 import inspect
+import re
+import textwrap
 import warnings
-from typing import Any, Callable, Dict, List, MutableMapping, Optional, Tuple
+from typing import Any, Callable, Dict, List, Optional, Tuple
 
 # 3rd party
 import dict2css
@@ -169,9 +178,10 @@ from sphinx.environment import BuildEnvironment
 from sphinx.util.docutils import SphinxDirective
 
 # this package
-from sphinx_toolbox.utils import OptionSpec, Purger, SphinxExtMetadata, flag
+from sphinx_toolbox import _css
+from sphinx_toolbox.utils import Config, OptionSpec, Purger, SphinxExtMetadata, flag, metadata_add_version
 
-__all__ = [
+__all__ = (
 		"InstallationDirective",
 		"ExtensionsDirective",
 		"make_installation_instructions",
@@ -184,9 +194,27 @@ __all__ = [
 		"extensions_node_purger",
 		"copy_asset_files",
 		"setup",
-		]
+		)
 
-installation_node_purger = Purger("all_installation_node_nodes")
+
+class _Purger(Purger):
+
+	def purge_nodes(self, app: Sphinx, env: BuildEnvironment, docname: str) -> None:  # pragma: no cover
+		"""
+		Remove all redundant nodes.
+
+		:param app: The Sphinx application.
+		:param env: The Sphinx build environment.
+		:param docname: The name of the document to remove nodes for.
+		"""
+
+		if not hasattr(env, self.attr_name):
+			return
+
+		setattr(env, self.attr_name, [])
+
+
+installation_node_purger = _Purger("all_installation_node_nodes")
 extensions_node_purger = Purger("all_extensions_node_nodes")
 
 
@@ -196,19 +224,24 @@ class Sources(List[Tuple[str, str, Callable, Callable, Optional[Dict[str, Callab
 
 	The syntax of each entry is:
 
-	``(option_name, source_name, getter_function, validator_function, extra_options)``
+	.. code-block:: python
 
-	* a string to use in the directive to specify the source to use,
-	* a string to use in the tabs to indicate the installation source,
-	* the function that returns the installation instructions,
-	* a function to validate the option value provided by the user,
-	* a mapping of additional options for the directive that are used by the getter_function.
+		(option_name, source_name, getter_function, validator_function, extra_options)
+
+	* ``option_name`` -- a string to use in the directive to specify the source to use,
+	* ``source_name`` -- a string to use in the tabs to indicate the installation source,
+	* ``getter_function`` -- the function that returns the installation instructions,
+	* ``validator_function`` -- a function to validate the option value provided by the user,
+	* ``extra_options`` -- a mapping of additional options for the directive that are used by the getter_function.
+
+	.. autoclasssumm:: Sources
+		:autosummary-sections: ;;
 	"""
 
 	def __init__(self, *args, **kwargs):
 		super().__init__(*args, **kwargs)
 
-	_args = ["options", "env"]
+	_args = ["options", "env"]  # pylint: disable=W8301
 	_directive_name = "installation"
 
 	def register(
@@ -282,7 +315,7 @@ def pypi_installation(
 	elif "project_name" in options:
 		pypi_name = options["project_name"]
 	else:
-		raise ValueError("No username supplied for the PyPI installation instructions.")
+		raise ValueError("No PyPI project name supplied for the PyPI installation instructions.")
 
 	return [".. prompt:: bash", '', f"    python3 -m pip install {pypi_name} --user"]
 
@@ -326,7 +359,7 @@ def conda_installation(
 		lines.append("First add the required channels\n\n.. prompt:: bash\n")
 
 		with lines.with_indent_size(lines.indent_size + 1):
-			for channel in channels:
+			for channel in channels:  # pylint: disable=use-list-copy
 				lines.append(f"conda config --add channels https://conda.anaconda.org/{channel.strip()}")
 
 		lines.append("\nThen install")
@@ -341,7 +374,7 @@ def conda_installation(
 		lines.append(f"conda install {conda_name}")
 		lines.blankline(ensure_single=True)
 
-	return lines
+	return list(lines)
 
 
 @sources.register("github", "GitHub", flag)
@@ -357,7 +390,10 @@ def github_installation(
 	"""
 
 	if "sphinx_toolbox.github" not in env.app.extensions:
-		raise ValueError("The 'sphinx_toolbox.github' is required for the :github: option but it is not enabled!")
+		raise ValueError(
+				"The 'sphinx_toolbox.github' extension is required for the "
+				":github: option but it is not enabled!"
+				)
 
 	username = getattr(env.config, "github_username", None)
 	if username is None:
@@ -383,15 +419,15 @@ class InstallationDirective(SphinxDirective):
 	optional_arguments: int = 1  # The name of the project; can be overridden for each source
 
 	# Registered sources
-	option_spec: OptionSpec = {  # type: ignore
+	option_spec: OptionSpec = {  # type: ignore[assignment]
 		source[0].lower(): source[3]
 		for source in sources  # pylint: disable=not-an-iterable
 		}
 
 	# Extra options for registered sources
-	for source in sources:  # pylint: disable=not-an-iterable
+	for source in sources:  # pylint: disable=not-an-iterable,loop-global-usage
 		if source[4] is not None:
-			option_spec.update(source[4])  # type: ignore
+			option_spec.update(source[4])  # type: ignore[attr-defined]
 
 	options: Dict[str, Any]
 	"""
@@ -409,13 +445,14 @@ class InstallationDirective(SphinxDirective):
 	The GitHub username and repository are configured in ``conf.py`` and are available in ``env.config``.
 	"""
 
-	def run(self) -> List[nodes.Node]:
-		"""
-		Create the installation node.
+	def run_html(self) -> List[nodes.Node]:
 		"""
+		Generate output for ``HTML`` builders.
 
-		if self.arguments:
-			self.options["project_name"] = self.arguments[0]
+		:rtype:
+
+		.. latex:clearpage::
+		"""
 
 		targetid = f'installation-{self.env.new_serialno("sphinx-toolbox installation"):d}'
 		targetnode = nodes.target('', '', ids=[targetid])
@@ -423,12 +460,62 @@ class InstallationDirective(SphinxDirective):
 		content = make_installation_instructions(self.options, self.env)
 		view = ViewList(content)
 
-		installation_node = nodes.paragraph(rawsource=content)  # type: ignore
-		self.state.nested_parse(view, self.content_offset, installation_node)  # type: ignore
+		installation_node = nodes.paragraph(rawsource=content)  # type: ignore[arg-type]
+		self.state.nested_parse(view, self.content_offset, installation_node)  # type: ignore[arg-type]
 		installation_node_purger.add_node(self.env, installation_node, targetnode, self.lineno)
 
 		return [targetnode, installation_node]
 
+	def run_generic(self) -> List[nodes.Node]:
+		"""
+		Generate generic reStructuredText output.
+		"""
+
+		targetid = f'installation-{self.env.new_serialno("sphinx-toolbox installation"):d}'
+		targetnode = nodes.target('', '', ids=[targetid])
+
+		tabs: Dict[str, List[str]] = _get_installation_instructions(self.options, self.env)
+
+		if not tabs:
+			warnings.warn("No installation source specified. No installation instructions will be shown.")
+			return []
+
+		nodes_to_return: List[nodes.Node] = [targetnode]
+
+		non_word_sub = re.compile(r'\W+')
+
+		for tab_name, tab_content in tabs.items():
+			# pylint: disable=loop-global-usage
+			section_id = non_word_sub.sub('_', tab_name)
+			section = nodes.section(ids=[f"{targetid}-{section_id}"])
+			section += nodes.title(tab_name, tab_name)
+			nodes_to_return.append(section)
+			installation_node_purger.add_node(self.env, section, targetnode, self.lineno)
+
+			view = ViewList(tab_content)
+			paragraph_node = nodes.paragraph(rawsource=tab_content)  # type: ignore[arg-type]
+			self.state.nested_parse(view, self.content_offset, paragraph_node)  # type: ignore[arg-type]
+			nodes_to_return.append(paragraph_node)
+			installation_node_purger.add_node(self.env, paragraph_node, targetnode, self.lineno)
+			# pylint: enable=loop-global-usage
+
+		return nodes_to_return
+
+	def run(self) -> List[nodes.Node]:
+		"""
+		Create the installation node.
+		"""
+
+		assert self.env.app.builder is not None
+
+		if self.arguments:
+			self.options["project_name"] = self.arguments[0]
+
+		if self.env.app.builder.format.lower() == "html":
+			return self.run_html()
+		else:
+			return self.run_generic()
+
 
 def make_installation_instructions(options: Dict[str, Any], env: BuildEnvironment) -> List[str]:
 	"""
@@ -436,28 +523,45 @@ def make_installation_instructions(options: Dict[str, Any], env: BuildEnvironmen
 
 	:param options:
 	:param env: The Sphinx build environment.
+	"""
 
-	:return:
+	tabs: Dict[str, List[str]] = _get_installation_instructions(options, env)
+
+	if not tabs:
+		warnings.warn("No installation source specified. No installation instructions will be shown.")
+		return []
+
+	content = StringList([".. tabs::", ''])
+	content.set_indent_type("    ")
+
+	for tab_name, tab_content in tabs.items():
+		with content.with_indent_size(1):
+			content.append(f".. tab:: {tab_name}")
+			content.blankline(ensure_single=True)
+
+		with content.with_indent_size(2):
+			content.extend([f"{line}" if line else '' for line in tab_content])  # pylint: disable=loop-invariant-statement
+
+	return list(content)
+
+
+def _get_installation_instructions(options: Dict[str, Any], env: BuildEnvironment) -> Dict[str, List[str]]:
+	"""
+	Returns a mapping of tab/section names to their content.
+
+	:param options:
+	:param env: The Sphinx build environment.
 	"""
 
 	tabs: Dict[str, List[str]] = {}
 
+	# pylint: disable=loop-global-usage,use-dict-comprehension
 	for option_name, source_name, getter_function, validator_function, extra_options in sources:
+		# pylint: enable=loop-global-usage,use-dict-comprehension
 		if option_name in options:
 			tabs[f"from {source_name}"] = getter_function(options, env)
 
-	if tabs:
-		content = [".. tabs::", '']
-
-		for tab_name, tab_content in tabs.items():
-			content.extend([f"    .. tab:: {tab_name}", ''])
-			content.extend([f"        {line}" if line else '' for line in tab_content])
-
-		return content
-
-	else:
-		warnings.warn("No installation source specified. No installation instructions will be shown.")
-		return []
+	return tabs
 
 
 class ExtensionsDirective(SphinxDirective):
@@ -467,7 +571,7 @@ class ExtensionsDirective(SphinxDirective):
 
 	has_content: bool = True  # Other required extensions, one per line
 	optional_arguments: int = 1  # The name of the project
-	option_spec: OptionSpec = {  # type: ignore
+	option_spec: OptionSpec = {  # type: ignore[assignment]
 		"import-name": directives.unchanged_required,  # If different to project name
 		"no-preamble": flag,
 		"no-postamble": flag,
@@ -477,6 +581,10 @@ class ExtensionsDirective(SphinxDirective):
 	def run(self) -> List[nodes.Node]:
 		"""
 		Create the extensions node.
+
+		:rtype:
+
+		.. latex:clearpage::
 		"""
 
 		extensions = list(self.content)
@@ -495,64 +603,77 @@ class ExtensionsDirective(SphinxDirective):
 		targetnode = nodes.target('', '', ids=[targetid])
 
 		top_text = (
-				f"Enable ``{self.arguments[0]}`` by adding the following "
-				f"to the ``extensions`` variable in your ``conf.py``:"
-				)
-		bottom_text = (
-				"For more information see "
-				"https://www.sphinx-doc.org/en/master/usage/extensions/index.html#third-party-extensions ."
+				".. latex:vspace:: 10px",
+				".. rst-class:: sphinx-toolbox-extensions",
+				'',
+				f"    Enable ``{self.arguments[0]}`` by adding the following",
+				f"    to the ``extensions`` variable in your ``conf.py``:",
 				)
+		bottom_text = textwrap.dedent(
+				r"""
+		.. raw:: latex
+
+			\begin{flushleft}
+
+		For more information see https://www.sphinx-doc.org/en/master/usage/extensions#third-party-extensions .
+
+		.. raw:: latex
+
+			\end{flushleft}
+		"""
+				).expandtabs(4).splitlines()
 
 		if "no-preamble" in self.options:
 			content = []
 		else:
-			content = [top_text, '']
+			content = [*top_text, '']
+
+		content.append(".. code-block:: python", )
+
+		if "no-postamble" not in self.options:
+			content.append("    :class: sphinx-toolbox-extensions")
 
 		content.extend([
-				".. code-block:: python",
 				'',
 				"    extensions = [",
 				"        ...",
 				])
 
-		for extension in extensions:
+		for extension in extensions:  # pylint: disable=use-list-copy
 			content.append(f"        {extension!r},")
 
 		content.extend(["        ]", ''])
 
 		if "no-postamble" not in self.options:
-			content.extend([bottom_text, ''])
+			content.extend(bottom_text)
 
-		view = ViewList(content)
-
-		extensions_node = nodes.paragraph(rawsource=content)  # type: ignore
-		self.state.nested_parse(view, self.content_offset, extensions_node)  # type: ignore
+		extensions_node = nodes.paragraph(rawsource=content)  # type: ignore[arg-type]
+		self.state.nested_parse(ViewList(content), self.content_offset, extensions_node)  # type: ignore[arg-type]
 		extensions_node_purger.add_node(self.env, extensions_node, targetnode, self.lineno)
 
 		return [targetnode, extensions_node]
 
 
-def copy_asset_files(app: Sphinx, exception: Exception = None):
+def copy_asset_files(app: Sphinx, exception: Optional[Exception] = None) -> None:
 	"""
 	Copy additional stylesheets into the HTML build directory.
 
+	.. versionadded:: 1.2.0
+
 	:param app: The Sphinx application.
 	:param exception: Any exception which occurred and caused Sphinx to abort.
-
-	.. versionadded:: 1.2.0
 	"""
 
 	if exception:  # pragma: no cover
 		return
 
-	style: MutableMapping[str, dict2css.Style] = {
-			'div[id*="installation"] .sphinx-tabs-tab': {"color": "#2980b9"},
-			"button.sphinx-tabs-tab,div.sphinx-tabs-panel": {"outline": (None, dict2css.IMPORTANT)},
-			}
+	if app.builder is None or app.builder.format.lower() != "html":  # pragma: no cover
+		return
 
 	static_dir = PathPlus(app.outdir) / "_static"
 	static_dir.maybe_make(parents=True)
-	(static_dir / "sphinx_toolbox_installation.css").write_clean(dict2css.dumps(style, minify=True))
+	dict2css.dump(_css.installation_styles, static_dir / "sphinx_toolbox_installation.css", minify=True)
+
 	(static_dir / "sphinx_toolbox_installation.js").write_lines([
 			"// Based on https://github.com/executablebooks/sphinx-tabs/blob/master/sphinx_tabs/static/tabs.js",
 			"// Copyright (c) 2017 djungelorm",
@@ -592,42 +713,48 @@ def copy_asset_files(app: Sphinx, exception: Exception = None):
 			"  }",
 			'',
 			'}',
+			'',
+			"// Compatibility with sphinx-tabs 2.1.0 and later",
+			"function deselectTabList(tab) {deselectTabset(tab)}",
+			'',
 			])
 
 
+def _on_config_inited(app: Sphinx, config: Config) -> None:
+	app.add_css_file("sphinx_toolbox_installation.css")
+	app.add_js_file("sphinx_toolbox_installation.js")
+
+
+@metadata_add_version
 def setup(app: Sphinx) -> SphinxExtMetadata:
 	"""
 	Setup :mod:`sphinx_toolbox.installation`.
 
-	:param app: The Sphinx app.
-
 	.. versionadded:: 0.7.0
-	"""
 
-	# this package
-	from sphinx_toolbox import __version__
+	:param app: The Sphinx application.
+	"""
 
 	if "sphinx_inline_tabs" not in getattr(app, "extensions", ()):
 		app.setup_extension("sphinx_tabs.tabs")
 
 	app.setup_extension("sphinx-prompt")
+	app.setup_extension("sphinx_toolbox._css")
+	app.setup_extension("sphinx_toolbox.latex")
 
 	app.add_config_value("conda_channels", [], "env", types=[list])
 
 	# Instructions for installing a python package
 	app.add_directive("installation", InstallationDirective)
-	app.connect("env-purge-doc", installation_node_purger.purge_nodes)
+	app.connect("env-get-outdated", installation_node_purger.get_outdated_docnames)
+	# app.connect("env-purge-doc", installation_node_purger.purge_nodes)
 
 	# Instructions for enabling a sphinx extension
 	app.add_directive("extensions", ExtensionsDirective)
 	app.connect("env-purge-doc", extensions_node_purger.purge_nodes)
 
-	# Little CSS tweaks
-	app.add_css_file("sphinx_toolbox_installation.css")
-	app.add_js_file("sphinx_toolbox_installation.js")
+	# Ensure this happens after tabs.js has been added
+	app.connect("config-inited", _on_config_inited, priority=510)
 	app.connect("build-finished", copy_asset_files)
 
-	return {
-			"version": __version__,
-			"parallel_read_safe": True,
-			}
+	return {"parallel_read_safe": True}
