@@ -7,7 +7,7 @@ Extensions to :mod:`sphinx.ext.autodoc`.
 .. versionadded:: 0.6.0
 """
 #
-#  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
+#  Copyright © 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -56,22 +56,79 @@ Extensions to :mod:`sphinx.ext.autodoc`.
 #  |  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #
 
+# stdlib
+from typing import TYPE_CHECKING, Any, List, Optional, Tuple
+
 # 3rd party
+from docutils.statemachine import StringList
 from sphinx.application import Sphinx
+from sphinx.ext.autodoc import Documenter
 
 # this package
-from sphinx_toolbox import __version__
-from sphinx_toolbox.more_autodoc.no_docstring import automodule_add_nodocstring, no_docstring_process_docstring
-from sphinx_toolbox.utils import SphinxExtMetadata
+from sphinx_toolbox.utils import SphinxExtMetadata, metadata_add_version
 
-__all__ = ["setup"]
+if TYPE_CHECKING:
+	# 3rd party
+	from sphinx.ext.autodoc import ObjectMembers
+
+	ObjectMembers = ObjectMembers
+else:
+	ObjectMembers = List[Tuple[str, Any]]
+
+__all__ = ("setup", )
 
 
+def _documenter_add_content(
+		self: Documenter,
+		more_content: Optional[StringList],
+		no_docstring: bool = False,
+		) -> None:
+	"""
+	Add content from docstrings, attribute documentation and user.
+	"""
+
+	# set sourcename and add content from attribute documentation
+	sourcename = self.get_sourcename()
+	if self.analyzer:
+		attr_docs = self.analyzer.find_attr_docs()
+		if self.objpath:
+			key = ('.'.join(self.objpath[:-1]), self.objpath[-1])
+			if key in attr_docs:
+				no_docstring = True
+				# make a copy of docstring for attributes to avoid cache
+				# the change of autodoc-process-docstring event.
+				docstrings = [list(attr_docs[key])]
+
+				for i, line in enumerate(self.process_doc(docstrings)):
+					self.add_line(line, sourcename, i)
+
+	# add content from docstrings
+	if not no_docstring:
+		docstrings = self.get_doc() or []
+		if docstrings is None:
+			# Do not call autodoc-process-docstring on get_doc() returns None.
+			pass
+		else:
+			if not docstrings:
+				# append at least a dummy docstring, so that the event
+				# autodoc-process-docstring is fired and can add some
+				# content if desired
+				docstrings.append([])
+			for i, line in enumerate(self.process_doc(docstrings)):
+				self.add_line(line, sourcename, i)
+
+	# add additional content (e.g. from document), if present
+	if more_content:
+		for line, src in zip(more_content.data, more_content.items):
+			self.add_line(line, src[0], src[1])
+
+
+@metadata_add_version
 def setup(app: Sphinx) -> SphinxExtMetadata:
 	"""
 	Setup :mod:`sphinx_toolbox.more_autodoc`.
 
-	:param app: The Sphinx app.
+	:param app: The Sphinx application.
 	"""
 
 	# Setup sub-extensions
@@ -89,7 +146,4 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 	app.setup_extension("sphinx_toolbox.more_autodoc.overloads")
 	app.setup_extension("sphinx_toolbox.more_autodoc.generic_bases")
 
-	return {
-			"version": __version__,
-			"parallel_read_safe": True,
-			}
+	return {"parallel_read_safe": True}
