@@ -4,9 +4,8 @@
 r"""
 Specialized Documenter for regular expression variables, similar to :rst:dir:`autodata`.
 
-.. extensions:: sphinx_toolbox.more_autodoc.regex
-
 .. versionadded:: 1.2.0
+.. extensions:: sphinx_toolbox.more_autodoc.regex
 
 Usage
 -------
@@ -38,8 +37,16 @@ Usage
 		:type: string
 
 		Show this instead of the flags taken from the :class:`~typing.Pattern` object.
+		This should be correctly formatted for insertion into reStructuredText, such as ``:py:data:`re.ASCII```.
 
 
+	.. versionchanged:: 2.7.0
+
+		The flags :py:data:`re.DEBUG` and :py:data:`re.VERBOSE` are now hidden
+		as they don't affect the regex itself.
+
+.. latex:clearpage::
+
 .. rst:role:: regex
 
 	Formats a regular expression with coloured output.
@@ -48,9 +55,11 @@ Usage
 
 		:regex:`^Hello\s+[Ww]orld[.,](Lovely|Horrible) weather, isn't it (.*)?`
 
+	.. versionchanged:: 2.11.0  Now generates coloured output with the LaTeX builder.
+
 """
 #
-#  Copyright © 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
+#  Copyright © 2020-2022 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -129,42 +138,43 @@ from sre_constants import (
 		SUBPATTERN
 		)
 from textwrap import dedent
-from typing import Any, Callable, List, Pattern, Tuple
+from typing import Any, Callable, List, Optional, Pattern, Tuple
 
 # 3rd party
 import dict2css
-from consolekit.terminal_colours import Fore
 from docutils import nodes
 from docutils.nodes import Node, system_message
-from docutils.parsers.rst import roles
 from domdf_python_tools.paths import PathPlus
+from domdf_python_tools.stringlist import StringList
 from sphinx.application import Sphinx
 from sphinx.ext.autodoc import UNINITIALIZED_ATTR, ModuleDocumenter
+from sphinx.util import texescape
 from sphinx.util.docutils import SphinxRole
-from sphinx.writers.html import HTMLTranslator
+from sphinx.writers.html5 import HTML5Translator
 
 # this package
+from sphinx_toolbox import _css
 from sphinx_toolbox.more_autodoc.variables import VariableDocumenter
-from sphinx_toolbox.utils import SphinxExtMetadata, flag, metadata_add_version
+from sphinx_toolbox.utils import Config, SphinxExtMetadata, add_nbsp_substitution, flag, metadata_add_version
 
-__all__ = [
+__all__ = (
 		"RegexDocumenter",
 		"RegexParser",
 		"TerminalRegexParser",
 		"HTMLRegexParser",
+		"LaTeXRegexParser",
 		"parse_regex_flags",
 		"no_formatting",
 		"span",
+		"latex_textcolor",
 		"copy_asset_files",
 		"setup",
-		]
+		)
 
 
 class RegexDocumenter(VariableDocumenter):
 	"""
 	Specialized Documenter subclass for regex patterns.
-
-	.. versionadded:: 1.2.0
 	"""
 
 	directivetype = "data"
@@ -197,7 +207,7 @@ class RegexDocumenter(VariableDocumenter):
 
 		return isinstance(parent, ModuleDocumenter) and isattr and isinstance(member, Pattern)
 
-	def add_content(self, more_content: Any, no_docstring: bool = False):
+	def add_content(self, more_content: Any, no_docstring: bool = False) -> None:
 		"""
 		Add content from docstrings, attribute documentation and the user.
 
@@ -223,15 +233,15 @@ class RegexDocumenter(VariableDocumenter):
 
 		# add content from docstrings
 		if not no_docstring:
-			docstrings = self.get_doc()
+			docstrings = self.get_doc() or []
 			if not docstrings:
 				# append at least a dummy docstring, so that the event
 				# autodoc-process-docstring is fired and can add some
 				# content if desired
 				docstrings.append([])
 
-			if docstrings == [["Compiled regular expression objects", '']]:
-				docstrings = [["Compiled regular expression object.", '']]
+			if docstrings == [["Compiled regular expression objects", '']] or docstrings == [[]]:
+				docstrings = [["Compiled regular expression object.", '']]  # pylint: disable=W8301
 
 			for i, line in enumerate(self.process_doc(docstrings)):
 				self.add_line(line, sourcename, i)
@@ -249,6 +259,19 @@ class RegexDocumenter(VariableDocumenter):
 			self.add_line('', sourcename)
 			self.add_line('', sourcename)
 
+			the_flag: Optional[str] = None
+
+			if not no_flag:
+				if "flag" in self.options:
+					the_flag = self.options["flag"]
+				else:
+					raw_flags = self.object.flags
+					raw_flags = (raw_flags & ~re.DEBUG) & ~re.VERBOSE
+					the_flag = parse_regex_flags(raw_flags)
+
+			if no_value and not the_flag:
+				return
+
 			self.add_line(".. csv-table::", sourcename)
 			self.add_line("     :widths: auto", sourcename)
 			self.add_line("     :stub-columns: 1", sourcename)
@@ -279,18 +302,12 @@ class RegexDocumenter(VariableDocumenter):
 
 				self.add_line(f'     **Pattern**, ":regex:`{the_pattern}`"', sourcename)
 
-			if not no_flag:
-				if "flag" in self.options:
-					the_flag = self.options["flag"]
-				else:
-					the_flag = parse_regex_flags(self.object.flags)
-
-				if the_flag:
-					self.add_line(f"     **Flags**, {the_flag}", sourcename)
+			if the_flag:
+				self.add_line(f"     **Flags**, {the_flag}", sourcename)
 
 			self.add_line('', sourcename)
 
-	def add_directive_header(self, sig: str):
+	def add_directive_header(self, sig: str) -> None:
 		"""
 		Add the directive's header.
 
@@ -308,10 +325,6 @@ def parse_regex_flags(flags: int) -> str:
 	Convert regex flags into "bitwise-or'd" Sphinx xrefs.
 
 	:param flags:
-
-	:rtype:
-
-	.. versionadded:: 1.2.0
 	"""
 
 	buf = []
@@ -339,11 +352,8 @@ def no_formatting(value: Any) -> str:
 	No-op that returns the value as a string.
 
 	Used for unformatted output.
-
-	:rtype:
-
-	.. versionadded:: 1.2.0
 	"""
+
 	return str(value)
 
 
@@ -351,7 +361,7 @@ class RegexParser:
 	r"""
 	Parser for regular expressions that outputs coloured output.
 
-	The formatting is controlled by the following variables:
+	The formatting is controlled by the following callable attributes:
 
 	* ``AT_COLOUR`` -- Used for e.g. :regex:`^\A\b\B\Z$`
 	* ``SUBPATTERN_COLOUR`` -- Used for the parentheses around subpatterns, e.g. :regex:`(Hello) World`
@@ -361,13 +371,12 @@ class RegexParser:
 	* ``CATEGORY_COLOUR`` -- Used for categories, e.g. :regex:`\d\D\s\D\w\W`
 	* ``BRANCH_COLOUR`` -- Used for branches, e.g. :regex:`(Lovely|Horrible) Weather`
 	* ``LITERAL_COLOUR`` -- Used for literal characters.
-	* ``ANY_COLOUR`` -- Used for the "any" dot ``.``.
+	* ``ANY_COLOUR`` -- Used for the "any" dot.
 
-	These are all :class:`~typing.Callable`\[[:class:`~typing.Any`], :class:`~typing.str`\].
+	These are all :class:`~typing.Callable`\[[:class:`~typing.Any`], :class:`str`\].
 
 	By default no formatting is performed.
-
-	.. versionadded:: 1.2.0
+	Subclasses should set these attributes to appropriate functions.
 	"""
 
 	# Colours
@@ -390,7 +399,7 @@ class RegexParser:
 
 		buf = []
 
-		def _parse_pattern(pattern):
+		def _parse_pattern(pattern) -> None:  # noqa: MAN001
 
 			for what, content in pattern:
 				# print(what, content)
@@ -456,7 +465,7 @@ class RegexParser:
 						buf.append(type(self).REPEAT_BRACE_COLOUR('{'))
 						buf.append(type(self).REPEAT_COLOUR(str(min_)))
 						buf.append(type(self).LITERAL_COLOUR(','))
-						buf.append(type(self).REPEAT_COLOUR(str(max)))
+						buf.append(type(self).REPEAT_COLOUR(str(max_)))
 						buf.append(type(self).REPEAT_BRACE_COLOUR('}'))
 					if what is MIN_REPEAT:
 						buf.append(type(self).REPEAT_COLOUR('?'))
@@ -506,7 +515,7 @@ class RegexParser:
 					buf.append(type(self).ANY_COLOUR('.'))
 					continue
 
-				print(what, content)
+				print(what, content)  # pragma: no cover
 
 		pattern = regex.pattern.replace('\t', r"\t")
 
@@ -515,7 +524,7 @@ class RegexParser:
 		trailing_spaces = len(tuple(itertools.takewhile(str.isspace, pattern[::-1])))
 		pattern = pattern.strip(' ')
 
-		tokens: List = list(sre_parse.parse(pattern, regex.flags))  # type: ignore
+		tokens: List = list(sre_parse.parse(pattern, regex.flags))  # type: ignore[call-overload]
 
 		if not leading_spaces:
 			while tokens[0] == (LITERAL, ord(' ')):
@@ -556,10 +565,6 @@ def span(css_class: str) -> Callable[[Any], str]:
 	Returns a function that wraps a value in a ``span`` tag with the given class.
 
 	:param css_class:
-
-	:rtype:
-
-	.. versionadded:: 1.2.0
 	"""
 
 	def f(value: Any) -> str:
@@ -568,6 +573,23 @@ def span(css_class: str) -> Callable[[Any], str]:
 	return f
 
 
+def latex_textcolor(colour_name: str) -> Callable[[Any], str]:
+	"""
+	Returns a function that wraps a value in a LaTeX ``textcolor`` command for the given colour.
+
+	.. versionadded:: 2.11.0
+
+	:param colour_name:
+	"""
+
+	def f(value: Any) -> str:
+		if value == ' ':
+			return "\\enspace"
+		return f'\\textcolor{{{colour_name}}}{{{texescape.escape(value)}}}'
+
+	return f
+
+
 class HTMLRegexParser(RegexParser):
 	r"""
 	:class:`~.RegexParser` that outputs styled HTML.
@@ -583,13 +605,11 @@ class HTMLRegexParser(RegexParser):
 	* ``CATEGORY_COLOUR`` -> ``regex_category`` -- Used for categories, e.g. :regex:`\d\D\s\D\w\W`
 	* ``BRANCH_COLOUR`` -> ``regex_branch`` -- Used for branches, e.g. :regex:`(Lovely|Horrible) Weather`
 	* ``LITERAL_COLOUR`` -> ``regex_literal`` -- Used for literal characters.
-	* ``ANY_COLOUR`` -> ``regex_any`` -- Used for the "any" dot ``.``.
+	* ``ANY_COLOUR`` -> ``regex_any`` -- Used for the "any" dot.
 
 	Additionally, all ``span`` tags the ``regex`` class,
 	and the surrounding ``code`` tag has the following classes:
 	``docutils literal notranslate regex``.
-
-	.. versionadded:: 1.2.0
 	"""
 
 	# Colours
@@ -619,56 +639,108 @@ class HTMLRegexParser(RegexParser):
 				)
 
 
+class LaTeXRegexParser(RegexParser):
+	r"""
+	:class:`~.RegexParser` that outputs styled LaTeX.
+
+	The formatting is controlled by the following functions, which
+	wrap the character in a LaTeX ``textcolor`` command for an appropriate colour:
+
+	* ``AT_COLOUR`` -> ``regex_at`` -- Used for e.g. :regex:`^\A\b\B\Z$`
+	* ``SUBPATTERN_COLOUR`` -> ``regex_subpattern`` -- Used for the parentheses around subpatterns, e.g. :regex:`(Hello) World`
+	* ``IN_COLOUR`` -> ``regex_in`` -- Used for the square brackets around character sets, e.g. :regex:`[Hh]ello`
+	* ``REPEAT_COLOUR`` -> ``regex_repeat`` -- Used for repeats, e.g. :regex:`A?B+C*D{2,4}E{5}`
+	* ``REPEAT_BRACE_COLOUR`` -> ``regex_repeat_brace`` -- Used for the braces around numerical repeats.
+	* ``CATEGORY_COLOUR`` -> ``regex_category`` -- Used for categories, e.g. :regex:`\d\D\s\D\w\W`
+	* ``BRANCH_COLOUR`` -> ``regex_branch`` -- Used for branches, e.g. :regex:`(Lovely|Horrible) Weather`
+	* ``LITERAL_COLOUR`` -> ``regex_literal`` -- Used for literal characters.
+	* ``ANY_COLOUR`` -> ``regex_any`` -- Used for the "any" dot.
+
+	.. versionadded:: 2.11.0
+	"""
+
+	# Colours
+	AT_COLOUR = latex_textcolor("regex_at")
+	SUBPATTERN_COLOUR = latex_textcolor("regex_subpattern")
+	IN_COLOUR = latex_textcolor("regex_in")
+	REPEAT_COLOUR = latex_textcolor("regex_repeat")
+	REPEAT_BRACE_COLOUR = latex_textcolor("regex_repeat_brace")
+	CATEGORY_COLOUR = latex_textcolor("regex_category")
+	BRANCH_COLOUR = latex_textcolor("regex_branch")
+	LITERAL_COLOUR = latex_textcolor("regex_literal")
+	ANY_COLOUR = latex_textcolor("regex_any")
+
+	def parse_pattern(self, regex: Pattern) -> str:
+		"""
+		Parse the given regular expression and return the formatted pattern.
+
+		:param regex:
+		"""
+
+		return f"\\sphinxcode{{\\sphinxupquote{{{super().parse_pattern(regex)}}}}}"
+
+
 class TerminalRegexParser(RegexParser):
 	r"""
 	:class:`~.RegexParser` that outputs ANSI coloured output for the terminal.
 
 
-	The formatting is controlled by the following functions,
-	which are instances of :class:`consolekit.terminal_colours.Colour`:
+	The formatting is controlled by the following callable attributes,
+	which set ANSI escape codes for the appropriate colour:
 
-	* ``AT_COLOUR`` -> :attr:`~consolekit.terminal_colours.Fore.YELLOW` -- Used for e.g. :regex:`^\A\b\B\Z$`
-	* ``SUBPATTERN_COLOUR`` -> :attr:`~consolekit.terminal_colours.Fore.LIGHTYELLOW_EX` -- Used for the parentheses around subpatterns, e.g. :regex:`(Hello) World`
-	* ``IN_COLOUR`` -> :attr:`~consolekit.terminal_colours.Fore.LIGHTRED_EX` -- Used for the square brackets around character sets, e.g. :regex:`[Hh]ello`
-	* ``REPEAT_COLOUR`` -> :attr:`~consolekit.terminal_colours.Fore.LIGHTBLUE_EX` -- Used for repeats, e.g. :regex:`A?B+C*D{2,4}E{5}`
-	* ``REPEAT_BRACE_COLOUR`` -> :attr:`~consolekit.terminal_colours.Fore.YELLOW` -- Used for the braces around numerical repeats.
-	* ``CATEGORY_COLOUR`` -> :attr:`~consolekit.terminal_colours.Fore.LIGHTYELLOW_EX` -- Used for categories, e.g. :regex:`\d\D\s\D\w\W`
-	* ``BRANCH_COLOUR`` -> :attr:`~consolekit.terminal_colours.Fore.YELLOW` -- Used for branches, e.g. :regex:`(Lovely|Horrible) Weather`
-	* ``LITERAL_COLOUR`` -> :attr:`~consolekit.terminal_colours.Fore.GREEN` -- Used for literal characters.
-	* ``ANY_COLOUR`` -> :attr:`~consolekit.terminal_colours.Fore.YELLOW` -- Used for the "any" dot ``.``.
-
-	.. versionadded:: 1.2.0
+	* ``AT_COLOUR`` -> YELLOW, Used for e.g. :regex:`^\A\b\B\Z$`
+	* ``SUBPATTERN_COLOUR`` -> LIGHTYELLOW_EX, Used for the parentheses around subpatterns, e.g. :regex:`(Hello) World`
+	* ``IN_COLOUR`` -> LIGHTRED_EX, Used for the square brackets around character sets, e.g. :regex:`[Hh]ello`
+	* ``REPEAT_COLOUR`` -> LIGHTBLUE_EX, Used for repeats, e.g. :regex:`A?B+C*D{2,4}E{5}`
+	* ``REPEAT_BRACE_COLOUR`` -> YELLOW, Used for the braces around numerical repeats.
+	* ``CATEGORY_COLOUR`` -> LIGHTYELLOW_EX, Used for categories, e.g. :regex:`\d\D\s\D\w\W`
+	* ``BRANCH_COLOUR`` -> YELLOW, Used for branches, e.g. :regex:`(Lovely|Horrible) Weather`
+	* ``LITERAL_COLOUR`` -> GREEN, Used for literal characters.
+	* ``ANY_COLOUR`` -> YELLOW, Used for the "any" dot.
 	"""
 
 	# Colours
-	AT_COLOUR = Fore.YELLOW
-	SUBPATTERN_COLOUR = Fore.LIGHTYELLOW_EX
-	IN_COLOUR = Fore.LIGHTRED_EX
-	REPEAT_COLOUR = Fore.LIGHTBLUE_EX
-	REPEAT_BRACE_COLOUR = Fore.YELLOW
-	CATEGORY_COLOUR = Fore.LIGHTYELLOW_EX
-	BRANCH_COLOUR = Fore.YELLOW
-	LITERAL_COLOUR = Fore.GREEN
-	ANY_COLOUR = Fore.YELLOW
+
+	@staticmethod
+	def AT_COLOUR(s: str) -> str:  # noqa: D102
+		return f"\x1b[33m{s}\x1b[39m"
+
+	@staticmethod
+	def SUBPATTERN_COLOUR(s: str) -> str:  # noqa: D102
+		return f"\x1b[93m{s}\x1b[39m"
+
+	@staticmethod
+	def IN_COLOUR(s: str) -> str:  # noqa: D102
+		return f"\x1b[91m{s}\x1b[39m"
+
+	@staticmethod
+	def REPEAT_COLOUR(s: str) -> str:  # noqa: D102
+		return f"\x1b[94m{s}\x1b[39m"
+
+	@staticmethod
+	def LITERAL_COLOUR(s: str) -> str:  # noqa: D102
+		return f"\x1b[32m{s}\x1b[39m"
+
+	REPEAT_BRACE_COLOUR = BRANCH_COLOUR = ANY_COLOUR = AT_COLOUR
+	CATEGORY_COLOUR = SUBPATTERN_COLOUR
 
 
 class RegexNode(nodes.literal):
 	"""
 	Docutils Node to show a highlighted regular expression.
-
-	.. versionadded:: 1.2.0
 	"""
 
-	def __init__(self, rawsource='', text='', *children, **attributes):
+	def __init__(self, rawsource: str = '', text: str = '', *children, **attributes) -> None:
 		super().__init__(rawsource, text, *children, **attributes)
-		self.pattern = re.compile(':'.join(rawsource.split(':')[2:])[1:-1])
+
+	@property
+	def pattern(self) -> re.Pattern:
+		return re.compile(':'.join(self.rawsource.split(':')[2:])[1:-1])
 
 
 class Regex(SphinxRole):
 	"""
 	Docutils role to show a highlighted regular expression.
-
-	.. versionadded:: 1.2.0
 	"""
 
 	def run(self) -> Tuple[List[Node], List[system_message]]:
@@ -676,70 +748,109 @@ class Regex(SphinxRole):
 		Process the content of the regex role.
 		"""
 
-		options = self.options.copy()  # type: ignore
+		options = self.options.copy()
 
 		return [RegexNode(self.rawtext, self.text, **options)], []
 
 
-def visit_regex_node(translator: HTMLTranslator, node: RegexNode):
+def visit_regex_node(translator: HTML5Translator, node: RegexNode) -> None:
 	"""
 	Visit an :class:`~.RegexNode`.
 
 	:param translator:
 	:param node: The node being visited.
-
-	.. versionadded:: 1.2.0
 	"""
 
 	translator.body.append(regex_parser.parse_pattern(node.pattern))
 
 
-def depart_regex_node(translator: HTMLTranslator, node: RegexNode):
+def depart_regex_node(translator: HTML5Translator, node: RegexNode) -> None:
 	"""
 	Depart an :class:`~.RegexNode`.
 
 	:param translator:
 	:param node: The node being visited.
-
-	.. versionadded:: 1.2.0
 	"""
 
 	translator.body.pop(-1)
 
 
-def copy_asset_files(app: Sphinx, exception: Exception = None):
+def visit_regex_node_latex(translator: HTML5Translator, node: RegexNode) -> None:
+	"""
+	Visit an :class:`~.RegexNode` with the LaTeX builder.
+
+	.. versionadded:: 2.11.0
+
+	:param translator:
+	:param node: The node being visited.
+	"""
+
+	translator.body.append(latex_regex_parser.parse_pattern(node.pattern))
+
+
+def depart_regex_node_latex(translator: HTML5Translator, node: RegexNode) -> None:
+	"""
+	Depart an :class:`~.RegexNode` with the LaTeX builder.
+
+	.. versionadded:: 2.11.0
+
+	:param translator:
+	:param node: The node being visited.
+	"""
+
+	translator.body.pop(-1)
+
+
+def copy_asset_files(app: Sphinx, exception: Optional[Exception] = None) -> None:
 	"""
 	Copy additional stylesheets into the HTML build directory.
 
 	:param app: The Sphinx application.
 	:param exception: Any exception which occurred and caused Sphinx to abort.
-
-	.. versionadded:: 1.2.0
 	"""
 
 	if exception:  # pragma: no cover
 		return
 
-	style = {
-			"span.regex_literal": {"color": "dimgrey"},
-			"span.regex_at": {"color": "orangered"},
-			"span.regex_repeat_brace": {"color": "orangered"},
-			"span.regex_branch": {"color": "orangered"},
-			"span.regex_subpattern": {"color": "dodgerblue"},
-			"span.regex_in": {"color": "darkorange"},
-			"span.regex_category": {"color": "darkseagreen"},
-			"span.regex_repeat": {"color": "orangered"},
-			"span.regex_any": {"color": "orangered"},
-			"code.regex": {"font-size": "80%"},
-			"span.regex": {"font-weight": "bold"},
-			}
+	if app.builder is None or app.builder.format.lower() != "html":  # pragma: no cover
+		return
 
 	static_dir = PathPlus(app.outdir) / "_static"
 	static_dir.maybe_make(parents=True)
-	(static_dir / "regex.css").write_clean(dict2css.dumps(style, minify=True))
+	dict2css.dump(_css.regex_styles, static_dir / "regex.css", minify=True)
 
 
 regex_parser = HTMLRegexParser()
+latex_regex_parser = LaTeXRegexParser()
+
+
+def configure(app: Sphinx, config: Config) -> None:
+	"""
+	Configure :mod:`sphinx_toolbox.code`.
+
+	.. versionadded:: 2.11.0
+
+	:param app: The Sphinx application.
+	:param config:
+	"""
+
+	latex_elements = getattr(app.config, "latex_elements", {})
+
+	latex_preamble = StringList(latex_elements.get("preamble", ''))
+	latex_preamble.blankline()
+	latex_preamble.append(r"\definecolor{regex_literal}{HTML}{696969}")
+	latex_preamble.append(r"\definecolor{regex_at}{HTML}{FF4500}")
+	latex_preamble.append(r"\definecolor{regex_repeat_brace}{HTML}{FF4500}")
+	latex_preamble.append(r"\definecolor{regex_branch}{HTML}{FF4500}")
+	latex_preamble.append(r"\definecolor{regex_subpattern}{HTML}{1e90ff}")
+	latex_preamble.append(r"\definecolor{regex_in}{HTML}{ff8c00}")
+	latex_preamble.append(r"\definecolor{regex_category}{HTML}{8fbc8f}")
+	latex_preamble.append(r"\definecolor{regex_repeat}{HTML}{FF4500}")
+	latex_preamble.append(r"\definecolor{regex_any}{HTML}{FF4500}")
+
+	latex_elements["preamble"] = str(latex_preamble)
+	app.config.latex_elements = latex_elements  # type: ignore[attr-defined]
+	add_nbsp_substitution(config)
 
 
 @metadata_add_version
@@ -747,23 +858,21 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 	"""
 	Setup :mod:`sphinx_toolbox.more_autodoc.regex`.
 
-	:param app: The Sphinx app.
-
-	:rtype:
-
-	.. versionadded:: 1.2.0
+	:param app: The Sphinx application.
 	"""
 
 	app.setup_extension("sphinx.ext.autodoc")
+	app.setup_extension("sphinx_toolbox._css")
+
+	app.connect("config-inited", configure)
+
 	app.add_autodocumenter(RegexDocumenter)
 
-	roles.register_local_role("regex", Regex())
+	app.add_role("regex", Regex())
 	app.add_node(
 			RegexNode,
 			html=(visit_regex_node, depart_regex_node),
+			latex=(visit_regex_node_latex, depart_regex_node_latex)
 			)
 
-	app.add_css_file("regex.css")
-	app.connect("build-finished", copy_asset_files)
-
 	return {"parallel_read_safe": True}
