@@ -9,7 +9,7 @@ name from its description if a description was given.
 .. versionadded:: 0.9.0
 
 
-**Example:**
+:bold-title:`Example`
 
 .. rest-example::
 
@@ -23,7 +23,9 @@ name from its description if a description was given.
 
 .. extensions:: sphinx_toolbox.tweaks.param_dash
 
-"""  # noqa D400
+-----
+
+"""  # noqa: D400
 #
 #  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
@@ -75,7 +77,7 @@ name from its description if a description was given.
 #
 
 # stdlib
-from typing import Dict, List, Tuple
+from typing import Dict, List, Optional, Tuple
 
 # 3rd party
 import sphinx.util.docfields
@@ -87,20 +89,30 @@ from sphinx.environment import BuildEnvironment
 # this package
 from sphinx_toolbox.utils import SphinxExtMetadata, metadata_add_version
 
-__all__ = ["make_field", "setup"]
+__all__ = ("setup", )
 
 
-def make_field(  # noqa D102
+def make_field(
 		self,
 		types: Dict[str, List[nodes.Node]],
 		domain: str,
 		items: Tuple,
-		env: BuildEnvironment = None,
+		env: Optional[BuildEnvironment] = None,
+		**kwargs,  # To support Sphinx 4.1 and later
 		) -> nodes.field:
 
 	def handle_item(fieldarg: str, content: List[nodes.Element]) -> nodes.paragraph:
 		par = nodes.paragraph()
-		par.extend(self.make_xrefs(self.rolename, domain, fieldarg, addnodes.literal_strong, env=env))
+		par.extend(
+				self.make_xrefs(
+						self.rolename,
+						domain,
+						fieldarg,
+						addnodes.literal_strong,
+						env=env,
+						**kwargs,  # To support Sphinx 4.1 and later
+						)
+				)
 
 		if fieldarg in types:
 			par += nodes.Text(" (")
@@ -136,7 +148,7 @@ def make_field(  # noqa D102
 	else:
 		bodynode = self.list_type()
 		for fieldarg, content in items:
-			bodynode += nodes.list_item('', handle_item(fieldarg, content))  # type: ignore
+			bodynode += nodes.list_item('', handle_item(fieldarg, content))  # type: ignore[assignment,operator]
 
 	fieldbody = nodes.field_body('', bodynode)
 
@@ -146,11 +158,11 @@ def make_field(  # noqa D102
 @metadata_add_version
 def setup(app: Sphinx) -> SphinxExtMetadata:
 	"""
-	Setup :mod:`sphinx_toolbox.param_dash`.
+	Setup :mod:`sphinx_toolbox.tweaks.param_dash`.
 
 	:param app: The Sphinx application.
 	"""
 
-	sphinx.util.docfields.TypedField.make_field = make_field  # type: ignore
+	sphinx.util.docfields.TypedField.make_field = make_field  # type: ignore[assignment]
 
 	return {"parallel_read_safe": True}
