@@ -7,9 +7,6 @@ Hack to get the docutils tab size, as there doesn't appear to be any other way.
 .. versionadded:: 1.0.0
 
 
-API Reference
----------------
-
 You probably don't need to use this extension directly, but if you're developing an
 extension of your own you can enable it like so:
 
@@ -57,32 +54,25 @@ from sphinx.application import Sphinx
 from sphinx.parsers import RSTParser
 
 # this package
-from sphinx_toolbox.utils import SphinxExtMetadata
+from sphinx_toolbox.utils import SphinxExtMetadata, metadata_add_version
 
-__all__ = ["setup"]
+__all__ = ("setup", )
 
 
+@metadata_add_version
 def setup(app: Sphinx) -> SphinxExtMetadata:
 	"""
 	Setup :mod:`sphinx_toolbox.tweaks.tabsize`.
 
-	:param app: The Sphinx app.
-
-	.. versionadded:: 1.0.0
+	:param app: The Sphinx application.
 	"""
 
-	# this package
-	from sphinx_toolbox import __version__
-
 	class CustomRSTParser(RSTParser):
 
 		def parse(self, inputstring: Union[str, StringList], document: document) -> None:
-			app.config.docutils_tab_width = document.settings.tab_width  # type: ignore
+			app.config.docutils_tab_width = document.settings.tab_width  # type: ignore[attr-defined]
 			super().parse(inputstring, document)
 
 	app.add_source_parser(CustomRSTParser, override=True)
 
-	return {
-			"version": __version__,
-			"parallel_read_safe": True,
-			}
+	return {"parallel_read_safe": True}
